powered by
Brown.tfl
Brown.spc
Brown.emp.vgc
zipfR
tfl
spc
vgc
These data were extracted from the Brown corpus (see Kucera and Francis 1967).
V
V(1)
We removed numbers and other forms of non-linguistic material before collecting word counts from the Brown.
BrownSubsets
data(Brown.tfl) summary(Brown.tfl) data(Brown.spc) summary(Brown.spc) data(Brown.emp.vgc) summary(Brown.emp.vgc)
Run the code above in your browser using DataLab