N.tfl) and vocabulary size
(V.tfl) of the type frequency list represented by a tfl
object, as well as class sizes (Vm.tfl) of the corresponding
frequency spectrum. Note that these functions are not user-visible. They can be called
implicitly through the generic methods N, V and
Vm, applied to an object of type tfl.
## S3 method for class 'tfl':
N(obj, ...) ## S3 method for class 'tfl':
V(obj, ...)
## S3 method for class 'tfl':
Vm(obj, m, ...)
tfl, representing an observed
type frequency listN.tfl returns the sample size $N$, V.tfl returns the
vocabulary size $V$ (or expected vocabulary size $E[V]$), and
Vm.tfl returns the number of types that occur exactly $m$
times in the sample, i.e. the class size $V_m$.tfl2spc first.
For an incomplete type frequency list, Vm.tfl will return
NA if m is outside the range of listed frequencies
(i.e. for m < f.min or m > f.max).N, V, Vm for the generic
methods and links to other implementations tfl for details on type frequency list objects and links
to other relevant functions